#[repr(transparent)]pub struct PkcCfg(pub u32);Expand description
Configuration register
Tuple Fields
0: u32Implementations
Sourceimpl PkcCfg
impl PkcCfg
Sourcepub const fn idleop(&self) -> bool
pub const fn idleop(&self) -> bool
Idle operation feature not available in this version (flag is don’t care).
Sourcepub const fn set_idleop(&mut self, val: bool)
pub const fn set_idleop(&mut self, val: bool)
Idle operation feature not available in this version (flag is don’t care).
Sourcepub const fn clkrnd(&self) -> bool
pub const fn clkrnd(&self) -> bool
Clock randomization feature not available in this version (flag is don’t care).
Sourcepub const fn set_clkrnd(&mut self, val: bool)
pub const fn set_clkrnd(&mut self, val: bool)
Clock randomization feature not available in this version (flag is don’t care).
Sourcepub const fn redmulnoise(&self) -> bool
pub const fn redmulnoise(&self) -> bool
Noise in reduced multiplier mode feature not available in this version (flag is don’t care).
Sourcepub const fn set_redmulnoise(&mut self, val: bool)
pub const fn set_redmulnoise(&mut self, val: bool)
Noise in reduced multiplier mode feature not available in this version (flag is don’t care).
Sourcepub const fn rnddly(&self) -> u8
pub const fn rnddly(&self) -> u8
Random delay feature not available in this version (flag is don’t care).
Sourcepub const fn set_rnddly(&mut self, val: u8)
pub const fn set_rnddly(&mut self, val: u8)
Random delay feature not available in this version (flag is don’t care).
Sourcepub const fn sbxnoise(&self) -> bool
pub const fn sbxnoise(&self) -> bool
Noise feature not available in this version (flag is don’t care).
Sourcepub const fn set_sbxnoise(&mut self, val: bool)
pub const fn set_sbxnoise(&mut self, val: bool)
Noise feature not available in this version (flag is don’t care).
Sourcepub const fn alpnoise(&self) -> bool
pub const fn alpnoise(&self) -> bool
Noise feature not available in this version (flag is don’t care).
Sourcepub const fn set_alpnoise(&mut self, val: bool)
pub const fn set_alpnoise(&mut self, val: bool)
Noise feature not available in this version (flag is don’t care).
Sourcepub const fn fmulnoise(&self) -> bool
pub const fn fmulnoise(&self) -> bool
Noise feature not available in this version (flag is don’t care).
Sourcepub const fn set_fmulnoise(&mut self, val: bool)
pub const fn set_fmulnoise(&mut self, val: bool)
Noise feature not available in this version (flag is don’t care).